function [ret,dec_values] = do_binary_cross_validation_loso(y, x, param, session, list,stdze,permuteLabs)
%DO_BINARY_CROSS_VALIDATION_LOSO
% loso - leave one session out
%
% Inputs: y - class labels
%         x - features
%         param - string liblinear parameters (e.g., -s 0 for L2)
%         session - session number per event
%         list - list per event
% Outputs: ret - performance value, as specified in validation_function,
% currently implemented to use AUC

% check input whether to zscore features within session. default = true
if ~exist('stdze','var')
    stdze = true;
end
% check input indicating whether to permute the training labels.
if ~exist('permuteLabs','var')
    permuteLabs = false;
elseif isempty(permuteLabs)
    permuteLabs = false;
end

len = length(y);
dec_values = [];
labels = [];

[nr_fold, selector] = make_folds(session);

for i = 1:nr_fold % Cross training : folding
    test_ind = selector==i;
    train_ind = [1:len]';
    train_ind(test_ind) = [];
    % find number of positive and negative class, for weighting
    
    % old method of adjusting penalty that assigned larger penalty to wrong
    % (larger) class:
    n_pos = numel(find(y(train_ind)==1))/numel(y(train_ind));
    n_neg = numel(find(y(train_ind)==-1))/numel(y(train_ind));
    mean_tmp = mean([n_pos n_neg]);
    n_pos = n_pos/mean_tmp;n_neg = n_neg/mean_tmp;
    
    % invert the weights on the penalty, to account for class imbalance
    tmp_pos = n_pos;
    n_pos = n_neg;
    n_neg = tmp_pos; clear tmp_pos;
    
    % formatting
    n_pos = sprintf('%f',n_pos);
    n_neg = sprintf('%f',n_neg);
    
    tmp_param = [param ' -w1 ' n_pos ' -w-1 ' n_neg];
    
    % standardize the training features, and store mean and sd to normalize
    % the test features
    if stdze
        [tmp, scratch] = standardize(x(train_ind,:), session(train_ind));
    else
        tmp = x(train_ind,:);
    end
    
    model = train(y(train_ind),tmp,tmp_param);
    
    % standardize the test features by the training mean and std
    if stdze
        [tmp, ~] = standardize(x(test_ind,:), session(test_ind));
    else
        tmp = x(test_ind,:);
    end
    
    
    [pred, acc, dec] = predict(y(test_ind),tmp,model,'-b 1');

    dec_values = vertcat(dec_values, dec(:,1));
    labels = vertcat(labels, y(test_ind));
end


disp(sprintf('Cross Validation:'));
[~,~,~,ret] = perfcurve(labels,dec_values,1);
% 
function [nr_fold, selector] = make_folds(session)

[~,~,selector] = unique(session','stable');
nr_fold = length(unique(selector));

function [pat, scratch] = standardize(pat, session)

sess = unique(session);

scratch = struct();
scratch.sess = sess;

for cS = 1:length(sess)
    
scratch.mean(cS,:)  = nanmean(pat(session==sess(cS),:));
scratch.std(cS,:)   = nanstd(pat(session==sess(cS),:));

pat(session==sess(cS),:) = bsxfun(@minus, pat(session==sess(cS),:),...
    scratch.mean(cS,:));
pat(session==sess(cS),:) = bsxfun(@rdivide, pat(session==sess(cS),:),...
    scratch.std(cS,:));

end
